@@ -119,8 +119,8 @@ void parse_rcfile(const char *filename, rckeys * keys)
 	if (fp) {
 		while (fgets(temp, 128, fp)) {
 			key = 0;
-			q = strdup(temp);
-			q = strtok(q, tokens);
+			char *t = strdup(temp);
+			q = strtok(t, tokens);
 			while (key >= 0 && keys[key].label) {
 				if ((!strcmp(q, keys[key].label))) {
 					p = strstr(temp, keys[key].label);
@@ -134,7 +134,7 @@ void parse_rcfile(const char *filename, rckeys * keys)
 				} else
 					key++;
 			}
-			free(q);
+			free(t);
 		}
 		fclose(fp);
 	}
